@@ -50,7 +50,11 @@
 #if LINUX_VERSION_CODE >= KERNEL_VERSION(3, 10, 0)
 #include <linux/magic.h>
 #endif
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(5, 15, 0)
+#include <linux/stdarg.h>
+#else
 #include <stdarg.h>
+#endif
 #include <linux/uaccess.h>
 #if LINUX_VERSION_CODE >= KERNEL_VERSION(4, 11, 0)
 #include <linux/sched/signal.h>
@@ -66,6 +70,10 @@
 #include <uapi/linux/mount.h>
 #endif
 
+#ifndef fallthrough
+#define fallthrough do {} while (0)
+#endif
+
 #ifndef current_uid
 #define current_uid()   (current->uid)
 #endif
